Annotation Type Hints
=====================

``colour.hints``

.. currentmodule:: colour.hints

.. autosummary::
    :toctree: generated/

    ArrayLike
    NDArray
    ModuleType
    Any
    Callable
    ClassVar
    Dict
    Generator
    Iterable
    Iterator
    List
    Literal
    Mapping
    NewType
    Optional
    Protocol
    Sequence
    Set
    SupportsIndex
    TYPE_CHECKING
    TextIO
    Tuple
    Type
    TypeVar
    TypedDict
    Union
    cast
    overload
    runtime_checkable
    Self
    RegexFlag
    DTypeInt
    DTypeFloat
    DTypeReal
    DTypeComplex
    DTypeBoolean
    DType
    Real
    Dataclass
    NDArrayInt
    NDArrayFloat
    NDArrayReal
    NDArrayComplex
    NDArrayBoolean
    NDArrayStr
    ProtocolInterpolator
    ProtocolExtrapolator
    ProtocolLUTSequenceItem
    LiteralWarning
    LiteralChromaticAdaptationTransform
    LiteralColourspaceModel
    LiteralRGBColourspace
    LiteralLogEncoding
    LiteralLogDecoding
    LiteralOETF
    LiteralOETFInverse
    LiteralEOTF
    LiteralEOTFInverse
    LiteralCCTFEncoding
    LiteralCCTFDecoding
    LiteralOOTF
    LiteralOOTFInverse
    LiteralLUTReadMethod
    LiteralLUTWriteMethod



    LiteralFontScaling
